require 'spec_helper'

describe Linkificator::ConditionsStorage::Condition do
  context 'context section' do
    context 'target is' do
      let(:condition) {
        Linkificator::ConditionsStorage::Condition.new(
            context: {target: %w(http://example.com/a.*)}
        )
      }

      {
          'http://example.com/a/b' => true,
          'http://example.com/a/'  => true,
          'http://example.com/a'   => true,
          'http://example.com/'    => false

      }.each do |target, expected_result|
        it "match #{target} is #{expected_result}" do
          expect(condition.match?(target: target)).to eq(expected_result)
        end
      end
    end

    context 'target_not' do
      let(:condition) {
        Linkificator::ConditionsStorage::Condition.new(
            context: {target_not: %w(http://example.com/a/e/.* http://example.com/a/e2), }
        )
      }

      {
          'http://example.com/a/b'    => true,
          'http://example.com/a/e/'   => false,
          'http://example.com/a/e2'   => false,
          'http://example.com/a/e2/c' => true
      }.each do |target, expected_result|
        it "match #{target} is #{expected_result}" do
          expect(condition.match?(target: target)).to eq(expected_result)
        end
      end
    end

    context 'current is' do
      let(:condition) {
        Linkificator::ConditionsStorage::Condition.new(
            context: {current: %w(http://example.com/a.*)}
        )
      }

      {
          'http://example.com/a/b' => true,
          'http://example.com/a/'  => true,
          'http://example.com/a'   => true,
          'http://example.com/'    => false,
          'http://example.com/b'   => false
      }.each do |target, expected_result|
        it "match #{target} is #{expected_result}" do
          expect(condition.match?(current: target)).to eq(expected_result)
        end
      end
    end

    context 'current_not' do
      let(:condition) {
        Linkificator::ConditionsStorage::Condition.new(
            context: {current_not: %w(http://example.com/a.*)}
        )
      }

      {
          'http://example.com/a' => false,
          'http://example.com/'  => true,
          'http://example.com/b' => true
      }.each do |target, expected_result|
        it "match #{target} is #{expected_result}" do
          expect(condition.match?(current: target)).to eq(expected_result)
        end
      end
    end
  end

  context 'processing section' do
    context 'wrap_noindex' do
      let(:condition) {
        Linkificator::ConditionsStorage::Condition.new(
            processing: {wrap_noindex: true}
        )
      }
      it do
        expect(condition.link_to('text', 'http://example.com')).to eq('<noindex><a href="http://example.com">text</a></noindex>')
      end
    end

    context 'data_href' do
      let(:condition) {
        Linkificator::ConditionsStorage::Condition.new(
            processing: {data_href: true}
        )
      }
      it do
        expect(condition.link_to('text', 'http://example.com')).to eq('<a data-href="aHR0cDovL2V4YW1wbGUuY29t" href="#">text</a>')
      end
    end

    context 'rel_nofollow' do
      let(:condition) {
        Linkificator::ConditionsStorage::Condition.new(
            processing: {rel_nofollow: true}
        )
      }
      it do
        expect(condition.link_to('text', 'http://example.com')).to eq('<a href="http://example.com" rel="nofollow">text</a>')
      end
    end

    context 'combined' do
      let(:condition) {
        Linkificator::ConditionsStorage::Condition.new(
            processing: {
                wrap_noindex: true,
                data_href:    true,
                rel_nofollow: true
            }
        )
      }
      it do
        expect(condition.link_to('text', 'http://example.com')).to eq('<noindex><a data-href="aHR0cDovL2V4YW1wbGUuY29t" href="#" rel="nofollow">text</a></noindex>')
      end
    end

    context 'with block' do
      let(:condition) {
        Linkificator::ConditionsStorage::Condition.new(
            processing: {rel_nofollow: true}
        )
      }
      it do
        expect(condition.link_to('http://example.com'){ 'text' }).to eq('<a href="http://example.com" rel="nofollow">text</a>')
      end
    end

    context 'use custom link_to methods' do
      let(:condition) {
        Linkificator::ConditionsStorage::Condition.new(
            processing: {rel_nofollow: true},
            link_via: :custom_link_to
        )
      }
      it do
        expect_any_instance_of(Linkificator::ConditionsStorage::Condition::ViewContext).to receive(:custom_link_to)
        expect(condition.link_to('text', 'http://example.com')).to eq(nil)
      end
    end

  end
end
