require 'spec_helper'

describe Linkificator::ConditionsStorage do
  let(:storage) {
    Linkificator::ConditionsStorage.new([
                                            {
                                                context:    { target: %w(http://example.com/a/.*) },
                                                processing: { wrap_noindex: true }
                                            },
                                            {
                                                context:    { current: %w(http://example.dev/a/.*) },
                                                processing: { wrap_noindex: true }
                                            }
                                        ])
  }
  it 'selects condition' do
    expect(storage.condition_for(target: 'http://example.com/a/')).to be_instance_of(Linkificator::ConditionsStorage::Condition)
  end

  context '#link_to' do
    it 'dont match anything' do
      expect(storage.link_to('text', 'http://example.com/c')).to eq('<a href="http://example.com/c">text</a>')
    end
    it 'match by target' do
      expect(storage.link_to('text', 'http://example.com/a/b')).to eq('<noindex><a href="http://example.com/a/b">text</a></noindex>')
    end
    it 'match by current' do
      expect(storage.link_to('text', 'http://example.com/c', context: {current: 'http://example.dev/a/'}))
          .to eq('<noindex><a href="http://example.com/c">text</a></noindex>')
    end
  end
end
